@@ -1,4 +1,4 @@
-# Copyrights 2007-2022 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2007-2023 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.03.
@@ -8,7 +8,7 @@
 
 package Log::Report;
 use vars '$VERSION';
-$VERSION = '1.34';
+$VERSION = '1.35';
 
 use base 'Exporter';
 
@@ -25,7 +25,7 @@ my $lrm = 'Log::Report::Message';
 my @make_msg   = qw/__ __x __n __nx __xn N__ N__n N__w __p __px __np __npx/;
 my @functions  = qw/report dispatcher try textdomain/;
 my @reason_functions = qw/trace assert info notice warning
-   mistake error fault alert failure panic/;
+    mistake error fault alert failure panic/;
 
 our @EXPORT_OK = (@make_msg, @functions, @reason_functions);
 
@@ -69,9 +69,11 @@ sub report($@)
 
     my @disp;
     if(defined $try)
-    {   push @disp, @{$reporter->{needs}{$reason}||[]}
+    {   push @disp, @{$reporter->{needs}{$reason} || []}
             unless $stop || $try->hides($reason);
-        push @disp, $try if $try->needs($reason);
+
+        push @disp, $try
+            if $try->needs($reason) || $opts->{is_fatal};
     }
     else
     {   @disp = @{$reporter->{needs}{$reason} || []};
@@ -298,6 +300,8 @@ sub try(&@)
         if $reporter->{needs}{TRACE};
 
     my $disp = Log::Report::Dispatcher::Try->new(TRY => 'try', @_);
+
+    # L::R native messages are logged directly in $disp via @nested_tries
     push @nested_tries, $disp;
 
     # user's __DIE__ handlers would frustrate the exception mechanism
@@ -309,14 +313,15 @@ sub try(&@)
     else             { $ret = eval { $code->() } } # SCALAR context
 
     my $err  = $@;
-    pop @nested_tries;
+    pop @nested_tries;   # remove $disp
 
     my $is_exception = blessed $err && $err->isa('Log::Report::Exception');
     if(!$is_exception && $err && !$disp->wasFatal)
-    {   # Decode exceptions which do not origin from Log::Report reports
-        my($opts, $reason, $text) = blessed $err
-           ? Log::Report::Die::exception_decode($err)
-           : Log::Report::Die::die_decode($err, on_die => $disp->die2reason);
+    {   # Decode errors which do not origin from Log::Report reports
+        # Native exceptions are already logged.
+        my ($opts, $reason, $text) = blessed $err
+          ? Log::Report::Die::exception_decode($err)
+          : Log::Report::Die::die_decode($err, on_die => $disp->die2reason);
 
         $disp->log($opts, $reason, __$text);
     }
